==> wurld-0.4.tar.gz: wurld-0.4/src/gameobjs/ball.py <==
#==============================================================================
#
#  $Id$
#
"""
   A ball.  Test of spherical objects and sphere collision detection.
"""
#
#  Copyright (C) 2007 Michael A. Muller
#
#  Permission is granted to use, modify and redistribute this code,
#  providing that the following conditions are met:
#
#  1) This copyright/licensing notice must remain intact.
#  2) If the code is modified and redistributed, the modifications must 
#  include documentation indicating that the code has been modified.
#  3) The author(s) of this code must be indemnified and held harmless
#  against any damage resulting from the use of this code.
#
#  This code comes with ABSOLUTELY NO WARRANTEE, not even the implied 
#  warrantee of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
#
#==============================================================================

import wurld
from util import *

# load the texture
material = wurld.createTextureMaterial(wurld.createTexture('SmokeyBlack.png'),
                                       10,
                                       10
                                       )

# create a sphere
model = wurld.createModel()
model.addSphere(wurld.createSphereObj(wurld.createVector(0, 0, 0), 5, material))

# create a sprite moving along positive X
sprite = Sprite(model, wurld.createVector(-20, 10, 10),
                wurld.createVector(1, 0, 0)
                )

# create a sphere model collidable
collidable = wurld.createSimpleCollidable(model.getBoundingBox())
sphere = wurld.Sphere()
sphere.center = wurld.createVector(0, 0, 0)
sphere.radius = 5.0
collidable.setSphere(sphere)

# add it to the sprite
sprite.addCollidable(collidable)

==> wurld-0.5.tar.gz: wurld-0.5/src/gameobjs/ball.py <==
#==============================================================================
#
#  $Id$
#
"""
   A ball.  Test of spherical objects and sphere collision detection.
"""
#
#  Copyright (C) 2007 Michael A. Muller
#
#  Permission is granted to use, modify and redistribute this code,
#  providing that the following conditions are met:
#
#  1) This copyright/licensing notice must remain intact.
#  2) If the code is modified and redistributed, the modifications must 
#  include documentation indicating that the code has been modified.
#  3) The author(s) of this code must be indemnified and held harmless
#  against any damage resulting from the use of this code.
#
#  This code comes with ABSOLUTELY NO WARRANTEE, not even the implied 
#  warrantee of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
#
#==============================================================================

import wurld
from util import *

# load the texture
material = wurld.createTextureMaterial(wurld.createTexture('SmokeyBlack.png'),
                                       10,
                                       10
                                       )

# create a sphere
model = wurld.createModel()
model.addSphere(wurld.createSphereObj(wurld.createVector(0, 0, 0), 5, material))

class Ball(Sprite):
   def onCollision(self, *args):
      print 'got ball collision'
      vel = wurld.createVector(-self.velocity.x, -self.velocity.y,
                               -self.velocity.z
                               )
      self.velocity = vel

   def __init__(self, position, radius, velocity):
      # create a sprite moving along positive X
      Sprite.__init__(self, model, position, velocity)

      # create a sphere model collidable
      collidable = wurld.createSphereCollidable(self.moveable, 5.0)

      # add it to the sprite
      self.addCollidable(collidable)
      self.collisionCallback = self.onCollision

b0 = Ball(wurld.createVector(-20, 18, 10), 5.0, wurld.createVector(5, 0, 0))
b1 = Ball(wurld.createVector(100, 18, 10), 5.0, wurld.createVector(-5, 0, 0))
